Class: Aws::QLDB::Types::CreateLedgerResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qldb/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) for the ledger.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
# File 'lib/aws-sdk-qldb/types.rb', line 207

class CreateLedgerResponse < Struct.new(
  :name,
  :arn,
  :state,
  :creation_date_time,
  :permissions_mode,
  :deletion_protection,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The date and time, in epoch time format, when the ledger was created. (Epoch time format is the number of seconds elapsed since 12:00:00 AM January 1, 1970 UTC.)

Returns:

  • (Time)


207
208
209
210
211
212
213
214
215
216
217
# File 'lib/aws-sdk-qldb/types.rb', line 207

class CreateLedgerResponse < Struct.new(
  :name,
  :arn,
  :state,
  :creation_date_time,
  :permissions_mode,
  :deletion_protection,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection ⇒ Boolean

Specifies whether the ledger is protected from being deleted by any user. If not defined during ledger creation, this feature is enabled (true) by default.

If deletion protection is enabled, you must first disable it before you can delete the ledger. You can disable it by calling the UpdateLedger operation to set this parameter to false.

Returns:

  • (Boolean)


207
208
209
210
211
212
213
214
215
216
217
# File 'lib/aws-sdk-qldb/types.rb', line 207

class CreateLedgerResponse < Struct.new(
  :name,
  :arn,
  :state,
  :creation_date_time,
  :permissions_mode,
  :deletion_protection,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arn ⇒ String

The ARN of the customer managed KMS key that the ledger uses for encryption at rest. If this parameter is undefined, the ledger uses an Amazon Web Services owned KMS key for encryption.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
# File 'lib/aws-sdk-qldb/types.rb', line 207

class CreateLedgerResponse < Struct.new(
  :name,
  :arn,
  :state,
  :creation_date_time,
  :permissions_mode,
  :deletion_protection,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the ledger.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
# File 'lib/aws-sdk-qldb/types.rb', line 207

class CreateLedgerResponse < Struct.new(
  :name,
  :arn,
  :state,
  :creation_date_time,
  :permissions_mode,
  :deletion_protection,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#permissions_mode ⇒ String

The permissions mode of the ledger that you created.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
# File 'lib/aws-sdk-qldb/types.rb', line 207

class CreateLedgerResponse < Struct.new(
  :name,
  :arn,
  :state,
  :creation_date_time,
  :permissions_mode,
  :deletion_protection,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The current status of the ledger.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
# File 'lib/aws-sdk-qldb/types.rb', line 207

class CreateLedgerResponse < Struct.new(
  :name,
  :arn,
  :state,
  :creation_date_time,
  :permissions_mode,
  :deletion_protection,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end