Class: Aws::QLDB::Types::DescribeJournalS3ExportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::QLDB::Types::DescribeJournalS3ExportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qldb/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#export_description ⇒ Types::JournalS3ExportDescription
Information about the journal export job returned by a
DescribeJournalS3Exportrequest.
Instance Attribute Details
#export_description ⇒ Types::JournalS3ExportDescription
Information about the journal export job returned by a DescribeJournalS3Export request.
287 288 289 290 291 |
# File 'lib/aws-sdk-qldb/types.rb', line 287 class DescribeJournalS3ExportResponse < Struct.new( :export_description) SENSITIVE = [] include Aws::Structure end |