Class: Aws::QLDB::Types::JournalS3ExportDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-qldb/types.rb

Overview

Information about a journal export job, including the ledger name, export ID, creation time, current status, and the parameters of the original export creation request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#exclusive_end_timeTime

The exclusive end date and time for the range of journal contents that was specified in the original export request.



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end

#export_creation_timeTime

The date and time, in epoch time format, when the export job was created. (Epoch time format is the number of seconds elapsed since 12:00:00 AM January 1, 1970 UTC.)



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end

#export_idString

The UUID (represented in Base62-encoded text) of the journal export job.



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end

#inclusive_start_timeTime

The inclusive start date and time for the range of journal contents that was specified in the original export request.



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end

#ledger_nameString

The name of the ledger.



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end

#output_formatString

The output format of the exported journal data.



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role that grants QLDB permissions for a journal export job to do the following:

  • Write objects into your Amazon Simple Storage Service (Amazon S3) bucket.

  • (Optional) Use your customer managed key in Key Management Service (KMS) for server-side encryption of your exported data.



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end

#s3_export_configurationTypes::S3ExportConfiguration

The Amazon Simple Storage Service (Amazon S3) bucket location in which a journal export job writes the journal contents.



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current state of the journal export job.



746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/aws-sdk-qldb/types.rb', line 746

class JournalS3ExportDescription < Struct.new(
  :ledger_name,
  :export_id,
  :export_creation_time,
  :status,
  :inclusive_start_time,
  :exclusive_end_time,
  :s3_export_configuration,
  :role_arn,
  :output_format)
  SENSITIVE = []
  include Aws::Structure
end