Class: Aws::QLDB::Types::S3EncryptionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::QLDB::Types::S3EncryptionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-qldb/types.rb
Overview
The encryption settings that are used by a journal export job to write data in an Amazon Simple Storage Service (Amazon S3) bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of a symmetric encryption key in Key Management Service (KMS).
-
#object_encryption_type ⇒ String
The Amazon S3 object encryption type.
Instance Attribute Details
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of a symmetric encryption key in Key Management Service (KMS). Amazon S3 does not support asymmetric KMS keys.
You must provide a KmsKeyArn if you specify SSE_KMS as the
ObjectEncryptionType.
KmsKeyArn is not required if you specify SSE_S3 as the
ObjectEncryptionType.
1248 1249 1250 1251 1252 1253 |
# File 'lib/aws-sdk-qldb/types.rb', line 1248 class S3EncryptionConfiguration < Struct.new( :object_encryption_type, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#object_encryption_type ⇒ String
The Amazon S3 object encryption type.
To learn more about server-side encryption options in Amazon S3, see Protecting Data Using Server-Side Encryption in the Amazon S3 Developer Guide.
1248 1249 1250 1251 1252 1253 |
# File 'lib/aws-sdk-qldb/types.rb', line 1248 class S3EncryptionConfiguration < Struct.new( :object_encryption_type, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |